You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ph...@apache.org on 2011/09/26 10:05:07 UTC

svn commit: r1175706 - /subversion/branches/1.7.x/STATUS

Author: philip
Date: Mon Sep 26 08:05:06 2011
New Revision: 1175706

URL: http://svn.apache.org/viewvc?rev=1175706&view=rev
Log:
* STATUS: Add link to STMT_SELECT_NODE_CHILDREN_WALKER_INFO discussion

Modified:
    subversion/branches/1.7.x/STATUS

Modified: subversion/branches/1.7.x/STATUS
URL: http://svn.apache.org/viewvc/subversion/branches/1.7.x/STATUS?rev=1175706&r1=1175705&r2=1175706&view=diff
==============================================================================
--- subversion/branches/1.7.x/STATUS (original)
+++ subversion/branches/1.7.x/STATUS Mon Sep 26 08:05:06 2011
@@ -83,7 +83,8 @@ Candidate changes:
    Fix STMT_SELECT_NODE_CHILDREN_WALKER_INFO for correctness and speed.
    Justification:
      Recursive info and propset don't scale well with large working copies
-     and may possibly act on the wrong nodes.
+     and may possibly act on the wrong nodes.  Correctness discussion:
+     http://colabti.org/irclogger/irclogger_log/svn-dev?date=2011-09-02#l214
      On a Linux machine with a Subversion trunk working copy on a local disk
      running 'svn info --depth infinity' shows it to be 2 or 3 times faster.
      On a larger working copy it's orders of magnitude faster.